==> zio-aws-sagemaker_2.12-5.17.112.1-sources.jar: zio/aws/sagemaker/model/PipelineExecutionSummary.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import zio.aws.sagemaker.model.primitives.{
  PipelineExecutionName,
  PipelineExecutionDescription,
  Timestamp,
  PipelineExecutionArn
}
import scala.jdk.CollectionConverters._
final case class PipelineExecutionSummary(
    pipelineExecutionArn: Option[PipelineExecutionArn] = None,
    startTime: Option[Timestamp] = None,
    pipelineExecutionStatus: Option[
      zio.aws.sagemaker.model.PipelineExecutionStatus
    ] = None,
    pipelineExecutionDescription: Option[PipelineExecutionDescription] = None,
    pipelineExecutionDisplayName: Option[PipelineExecutionName] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.PipelineExecutionSummary = {
    import PipelineExecutionSummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.PipelineExecutionSummary
      .builder()
      .optionallyWith(
        pipelineExecutionArn.map(value =>
          PipelineExecutionArn.unwrap(value): java.lang.String
        )
      )(_.pipelineExecutionArn)
      .optionallyWith(startTime.map(value => Timestamp.unwrap(value): Instant))(
        _.startTime
      )
      .optionallyWith(pipelineExecutionStatus.map(value => value.unwrap))(
        _.pipelineExecutionStatus
      )
      .optionallyWith(
        pipelineExecutionDescription.map(value =>
          PipelineExecutionDescription.unwrap(value): java.lang.String
        )
      )(_.pipelineExecutionDescription)
      .optionallyWith(
        pipelineExecutionDisplayName.map(value =>
          PipelineExecutionName.unwrap(value): java.lang.String
        )
      )(_.pipelineExecutionDisplayName)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.PipelineExecutionSummary.ReadOnly =
    zio.aws.sagemaker.model.PipelineExecutionSummary.wrap(buildAwsValue())
}
object PipelineExecutionSummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.PipelineExecutionSummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.PipelineExecutionSummary =
      zio.aws.sagemaker.model.PipelineExecutionSummary(
        pipelineExecutionArn.map(value => value),
        startTime.map(value => value),
        pipelineExecutionStatus.map(value => value),
        pipelineExecutionDescription.map(value => value),
        pipelineExecutionDisplayName.map(value => value)
      )
    def pipelineExecutionArn: Option[PipelineExecutionArn]
    def startTime: Option[Timestamp]
    def pipelineExecutionStatus
        : Option[zio.aws.sagemaker.model.PipelineExecutionStatus]
    def pipelineExecutionDescription: Option[PipelineExecutionDescription]
    def pipelineExecutionDisplayName: Option[PipelineExecutionName]
    def getPipelineExecutionArn: ZIO[Any, AwsError, PipelineExecutionArn] =
      AwsError.unwrapOptionField("pipelineExecutionArn", pipelineExecutionArn)
    def getStartTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("startTime", startTime)
    def getPipelineExecutionStatus
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.PipelineExecutionStatus] =
      AwsError.unwrapOptionField(
        "pipelineExecutionStatus",
        pipelineExecutionStatus
      )
    def getPipelineExecutionDescription
        : ZIO[Any, AwsError, PipelineExecutionDescription] =
      AwsError.unwrapOptionField(
        "pipelineExecutionDescription",
        pipelineExecutionDescription
      )
    def getPipelineExecutionDisplayName
        : ZIO[Any, AwsError, PipelineExecutionName] =
      AwsError.unwrapOptionField(
        "pipelineExecutionDisplayName",
        pipelineExecutionDisplayName
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.PipelineExecutionSummary
  ) extends zio.aws.sagemaker.model.PipelineExecutionSummary.ReadOnly {
    override val pipelineExecutionArn: Option[PipelineExecutionArn] = scala
      .Option(impl.pipelineExecutionArn())
      .map(value =>
        zio.aws.sagemaker.model.primitives.PipelineExecutionArn(value)
      )
    override val startTime: Option[Timestamp] = scala
      .Option(impl.startTime())
      .map(value => zio.aws.sagemaker.model.primitives.Timestamp(value))
    override val pipelineExecutionStatus
        : Option[zio.aws.sagemaker.model.PipelineExecutionStatus] = scala
      .Option(impl.pipelineExecutionStatus())
      .map(value => zio.aws.sagemaker.model.PipelineExecutionStatus.wrap(value))
    override val pipelineExecutionDescription
        : Option[PipelineExecutionDescription] = scala
      .Option(impl.pipelineExecutionDescription())
      .map(value =>
        zio.aws.sagemaker.model.primitives.PipelineExecutionDescription(value)
      )
    override val pipelineExecutionDisplayName: Option[PipelineExecutionName] =
      scala
        .Option(impl.pipelineExecutionDisplayName())
        .map(value =>
          zio.aws.sagemaker.model.primitives.PipelineExecutionName(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.PipelineExecutionSummary
  ): zio.aws.sagemaker.model.PipelineExecutionSummary.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-sagemaker_2.12-5.17.129.2-sources.jar: zio/aws/sagemaker/model/PipelineExecutionSummary.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import zio.aws.sagemaker.model.primitives.{
  PipelineExecutionName,
  Timestamp,
  String3072,
  PipelineExecutionArn,
  PipelineExecutionDescription
}
import scala.jdk.CollectionConverters._
final case class PipelineExecutionSummary(
    pipelineExecutionArn: Option[PipelineExecutionArn] = None,
    startTime: Option[Timestamp] = None,
    pipelineExecutionStatus: Option[
      zio.aws.sagemaker.model.PipelineExecutionStatus
    ] = None,
    pipelineExecutionDescription: Option[PipelineExecutionDescription] = None,
    pipelineExecutionDisplayName: Option[PipelineExecutionName] = None,
    pipelineExecutionFailureReason: Option[String3072] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.PipelineExecutionSummary = {
    import PipelineExecutionSummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.PipelineExecutionSummary
      .builder()
      .optionallyWith(
        pipelineExecutionArn.map(value =>
          PipelineExecutionArn.unwrap(value): java.lang.String
        )
      )(_.pipelineExecutionArn)
      .optionallyWith(startTime.map(value => Timestamp.unwrap(value): Instant))(
        _.startTime
      )
      .optionallyWith(pipelineExecutionStatus.map(value => value.unwrap))(
        _.pipelineExecutionStatus
      )
      .optionallyWith(
        pipelineExecutionDescription.map(value =>
          PipelineExecutionDescription.unwrap(value): java.lang.String
        )
      )(_.pipelineExecutionDescription)
      .optionallyWith(
        pipelineExecutionDisplayName.map(value =>
          PipelineExecutionName.unwrap(value): java.lang.String
        )
      )(_.pipelineExecutionDisplayName)
      .optionallyWith(
        pipelineExecutionFailureReason.map(value =>
          String3072.unwrap(value): java.lang.String
        )
      )(_.pipelineExecutionFailureReason)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.PipelineExecutionSummary.ReadOnly =
    zio.aws.sagemaker.model.PipelineExecutionSummary.wrap(buildAwsValue())
}
object PipelineExecutionSummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.PipelineExecutionSummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.PipelineExecutionSummary =
      zio.aws.sagemaker.model.PipelineExecutionSummary(
        pipelineExecutionArn.map(value => value),
        startTime.map(value => value),
        pipelineExecutionStatus.map(value => value),
        pipelineExecutionDescription.map(value => value),
        pipelineExecutionDisplayName.map(value => value),
        pipelineExecutionFailureReason.map(value => value)
      )
    def pipelineExecutionArn: Option[PipelineExecutionArn]
    def startTime: Option[Timestamp]
    def pipelineExecutionStatus
        : Option[zio.aws.sagemaker.model.PipelineExecutionStatus]
    def pipelineExecutionDescription: Option[PipelineExecutionDescription]
    def pipelineExecutionDisplayName: Option[PipelineExecutionName]
    def pipelineExecutionFailureReason: Option[String3072]
    def getPipelineExecutionArn: ZIO[Any, AwsError, PipelineExecutionArn] =
      AwsError.unwrapOptionField("pipelineExecutionArn", pipelineExecutionArn)
    def getStartTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("startTime", startTime)
    def getPipelineExecutionStatus
        : ZIO[Any, AwsError, zio.aws.sagemaker.model.PipelineExecutionStatus] =
      AwsError.unwrapOptionField(
        "pipelineExecutionStatus",
        pipelineExecutionStatus
      )
    def getPipelineExecutionDescription
        : ZIO[Any, AwsError, PipelineExecutionDescription] =
      AwsError.unwrapOptionField(
        "pipelineExecutionDescription",
        pipelineExecutionDescription
      )
    def getPipelineExecutionDisplayName
        : ZIO[Any, AwsError, PipelineExecutionName] =
      AwsError.unwrapOptionField(
        "pipelineExecutionDisplayName",
        pipelineExecutionDisplayName
      )
    def getPipelineExecutionFailureReason: ZIO[Any, AwsError, String3072] =
      AwsError.unwrapOptionField(
        "pipelineExecutionFailureReason",
        pipelineExecutionFailureReason
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.PipelineExecutionSummary
  ) extends zio.aws.sagemaker.model.PipelineExecutionSummary.ReadOnly {
    override val pipelineExecutionArn: Option[PipelineExecutionArn] = scala
      .Option(impl.pipelineExecutionArn())
      .map(value =>
        zio.aws.sagemaker.model.primitives.PipelineExecutionArn(value)
      )
    override val startTime: Option[Timestamp] = scala
      .Option(impl.startTime())
      .map(value => zio.aws.sagemaker.model.primitives.Timestamp(value))
    override val pipelineExecutionStatus
        : Option[zio.aws.sagemaker.model.PipelineExecutionStatus] = scala
      .Option(impl.pipelineExecutionStatus())
      .map(value => zio.aws.sagemaker.model.PipelineExecutionStatus.wrap(value))
    override val pipelineExecutionDescription
        : Option[PipelineExecutionDescription] = scala
      .Option(impl.pipelineExecutionDescription())
      .map(value =>
        zio.aws.sagemaker.model.primitives.PipelineExecutionDescription(value)
      )
    override val pipelineExecutionDisplayName: Option[PipelineExecutionName] =
      scala
        .Option(impl.pipelineExecutionDisplayName())
        .map(value =>
          zio.aws.sagemaker.model.primitives.PipelineExecutionName(value)
        )
    override val pipelineExecutionFailureReason: Option[String3072] = scala
      .Option(impl.pipelineExecutionFailureReason())
      .map(value => zio.aws.sagemaker.model.primitives.String3072(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.PipelineExecutionSummary
  ): zio.aws.sagemaker.model.PipelineExecutionSummary.ReadOnly = new Wrapper(
    impl
  )
}
